from typing import (
    Any,
    Union,
)


SerializableData = Any
SerializedData = Union[str, bytes]
